require 'cocoapods-headermap/headers_store'

module Pod
    class Target
        class BuildSettings
            class PodTargetSettings < BuildSettings

                # Call `define_build_settings_method` with a given block in order to disable sorting.
                define_build_settings_method :header_search_paths, :build_setting => true, :memoized => true, :sorted => false do
                    paths = target.header_search_paths(:include_dependent_targets_for_test_spec => test_xcconfig? && non_library_spec, :include_dependent_targets_for_app_spec => app_xcconfig? && non_library_spec, :configuration => @configuration)
          
                    dependent_vendored_xcframeworks = []
                    dependent_vendored_xcframeworks.concat vendored_xcframeworks
                    dependent_vendored_xcframeworks.concat dependent_targets.flat_map { |pt| pt.build_settings[@configuration].vendored_xcframeworks }
                    paths.concat dependent_vendored_xcframeworks.
                      select { |xcf| xcf.build_type.static_library? }.
                      map { |xcf| "#{BuildSettings.xcframework_intermediate_dir(xcf)}/Headers" }.
                      compact
                    paths
                end

                # @return [Array<String>] The path of `hmap` file for this project
                define_build_settings_method :user_header_search_paths, :build_setting => true, :memoized => true, :sorted => false do
                    paths = ["${PODS_ROOT}/#{target.sandbox.headers_root.basename}/#{Sandbox::POD_PROJECT_HEADERS}.hmap"]
                    paths
                end
            end

            class AggregateTargetSettings < BuildSettings
                # # Call `define_build_settings_method` with a given block in order to disable sorting paths.
                define_build_settings_method :header_search_paths, :build_setting => true, :memoized => true, :sorted => false, :uniqued => true do
                    paths = []
          
                    if !target.build_as_framework? || !pod_targets.all?(&:should_build?)
                      paths.concat target.sandbox.public_headers.search_paths(target.platform)
                    end
          
                    # Make frameworks headers discoverable with any syntax (quotes,
                    # brackets, @import, etc.)
                    paths.concat pod_targets.
                      select { |pt| pt.build_as_framework? && pt.should_build? }.
                      map { |pt| pt.build_settings[@configuration].framework_header_search_path }
          
                    xcframework_library_headers = pod_targets.flat_map { |pt| pt.build_settings[@configuration].vendored_xcframeworks }.
                                                  select { |xcf| xcf.build_type.static_library? }.
                                                  map { |xcf| "#{BuildSettings.xcframework_intermediate_dir(xcf)}/Headers" }.
                                                  compact
          
                    paths.concat xcframework_library_headers
                    paths.concat target.search_paths_aggregate_targets.flat_map { |at| at.build_settings(configuration_name).header_search_paths }
                    paths
                end

                # @return [Array<String>] The path of `hmap` file for this project
                define_build_settings_method :user_header_search_paths, :build_setting => true, :memoized => true, :sorted => false do
                    paths = ["${PODS_ROOT}/#{target.sandbox.headers_root.basename}/#{Sandbox::POD_PROJECT_HEADERS}.hmap"]
                    paths
                end
            end
        end
    end
end
    