module Pod 
    class Configuration
        # Keepping all the symlink reference under the `$PODS_ROOT/Headers` directory.
        # Default is true for better compatibility.
        @keep_symlink_reference = true

        # Use this option to forbid the Xcode from automatically generating header map files.
        # Turn on this for better performance. Default is false.
        @disable_system_headermap = false
        
        # This option will turn on `USE_HEADERMAP` option for the specified target.
        # Use this to avoid some error when you have to use angle brackets to import header files without namespace.
        # For example `include <config.h>` in `ZBarSDK`.
        # Work when `disable_system_headermap` is true.
        @enabled_headermap_pods = ["ZBarSDK"]
        
        class << self
            attr_reader :keep_symlink_reference
            def keep_symlink_reference=(keep_symlink_reference)
                raise Informative, "[cocoapods-headermap]: Expecting Boolean type for `:keep_symlink_reference`!" unless [true, false].include?(keep_symlink_reference)
                @keep_symlink_reference = keep_symlink_reference
            end

            attr_reader :disable_system_headermap
            def disable_system_headermap=(disable_system_headermap)
                raise Informative "[cocoapods-headermap]: Expecting Boolean type for `:disable_system_headermap`!" unless [true, false].include?(disable_system_headermap)
                @disable_system_headermap = disable_system_headermap
            end

            attr_reader :enabled_headermap_pods
            def enabled_headermap_pods=(enabled_headermap_pods)
                raise Informative, "[cocoapods-headermap]: Expecting array type for `:enabled_headermap_pods`!" unless enabled_headermap_pods.is_a?(Array)
                @enabled_headermap_pods.concat enabled_headermap_pods
            end
        end
    end
end