require 'json'
require 'cocoapods-headermap/header_maps_generator'

module Pod
    class Installer
        class Xcode
            class PodsProjectGenerator
                class FileReferencesInstaller
                    
                    def link_headers
                        UI.message '- Linking headers' do
                            pod_targets.each do |pod_target|
                                next if pod_target.build_as_framework? && pod_target.should_build?
                                sync_modulemap_flags(pod_target)
                                create_symlink_reference(pod_target)
                                HeaderMapsGenerator.merge_target_headers(pod_target)
                            end
                        end
                    end

                    # Synchronize the information wether a target has it's own modulemap file.
                    def sync_modulemap_flags(pod_target)
                        pod_target.build_headers.user_clang_module = true if pod_target.file_accessors.first.module_map
                    end

                    # Creates the link to the headers of the Pod in the sandbox.
                    def create_symlink_reference(pod_target)
                        pod_target_header_mappings = pod_target.header_mappings_by_file_accessor.values
                        pod_target_header_mappings.each do |header_mappings|
                            header_mappings.each do |namespaced_path, files|
                                pod_target.build_headers.add_files(namespaced_path, files)
                            end
                        end

                        public_header_mappings = pod_target.public_header_mappings_by_file_accessor.values
                        public_header_mappings.each do |header_mappings|
                            header_mappings.each do |namespaced_path, files|
                                sandbox.public_headers.add_files(namespaced_path, files)
                            end
                        end
                    end
                end
            end
        end
    end
end
